@@ -41,7 +41,12 @@ class DepsOutdatedCommand(BaseCommand):
             ))
 
         if data:
-            print(make_json(data=data, key=self.config.get('filter')))
+            print(make_json(
+                data=data,
+                key=self.config.get('filter'),
+                colors=not self.config['nocolors'],
+                table=self.config['table'],
+            ))
             return False
 
         self.logger.info('all dependencies is up-to-date')
