@@ -27,6 +27,7 @@ _NAMES = (
 
     'generate authors',
     'generate config',
+    'generate contributing',
     'generate editorconfig',
     'generate license',
     'generate travis',
@@ -36,6 +37,7 @@ _NAMES = (
     'inspect gadget',
     'inspect self',
     'inspect venv',
+    'inspect project',
 
     'jail install',
     'jail list',
@@ -54,6 +56,10 @@ _NAMES = (
     'project build',
     'project bump',
     'project test',
+    'project validate',
+
+    'self uncache',
+    'self upgrade',
 
     'vendor download',
     'vendor import',
