@@ -10,15 +10,10 @@ from .base import BaseCommand
 
 class GenerateAuthorsCommand(BaseCommand):
     """Create AUTHORS file for project by git log.
-
-    https://dephell.readthedocs.io/en/latest/cmd-generate-authors.html
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell generate authors',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
