@@ -10,16 +10,11 @@ from .base import BaseCommand
 
 class GenerateEditorconfigCommand(BaseCommand):
     """Create EditorConfig for project.
-
-    https://dephell.readthedocs.io/en/latest/cmd-generate-editorconfig.html
     https://editorconfig.org/
     """
     @classmethod
     def get_parser(cls) -> ArgumentParser:
-        parser = ArgumentParser(
-            prog='dephell generate editorconfig',
-            description=cls.__doc__,
-        )
+        parser = cls._get_default_parser()
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
